#
# spec file for package ktexteditor
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define _tar_path 5.103
%bcond_without released
Name:           ktexteditor
Version:        5.111.0
Release:        1.1
Summary:        Embeddable text editor component
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  libeditorconfig-devel
BuildRequires:  libgit2-devel
BuildRequires:  cmake(KF5Archive) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Config) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5GuiAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5IconThemes) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Parts) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Sonnet) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5SyntaxHighlighting) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5TextWidgets) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5PrintSupport) >= 5.15.0
BuildRequires:  cmake(Qt5Qml) >= 5.15.0
BuildRequires:  cmake(Qt5Test) >= 5.15.0
BuildRequires:  cmake(Qt5Widgets) >= 5.15.0
BuildRequires:  cmake(Qt5Xml) >= 5.15.0
Requires:       syntax-highlighting >= %{_kf5_bugfix_version}
Obsoletes:      libKF5TextEditor4
Obsoletes:      libKF5TextEditor5

%description
KTextEditor provides a text editor component that can be embedded in
applications, either as a KPart or using the KF5::TextEditor library.

%package devel
Summary:        Header files for ktexteditor, an embeddable text editor component
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules
Requires:       cmake(KF5Parts) >= %{_kf5_bugfix_version}
Requires:       cmake(KF5SyntaxHighlighting) >= %{_kf5_bugfix_version}

%description devel
KTextEditor provides a text editor component that can be embedded in
applications, either as a KPart or using the KF5::TextEditor library.

This subpackage provides the header files.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DSYSCONF_INSTALL_DIR=%{_kf5_sysconfdir} -DENABLE_KAUTH:BOOL=OFF
%cmake_build

%install
%kf5_makeinstall -C build

%fdupes %{buildroot}

%find_lang ktexteditor5

%ldconfig_scriptlets

%files -n %{name}-lang -f ktexteditor5.lang

%files
%license LICENSES/*
%doc README*
%{_kf5_libdir}/libKF5TextEditor.so.*
%{_kf5_sharedir}/katepart5/
%{_kf5_servicesdir}/
%{_kf5_plugindir}/
%{_kf5_servicetypesdir}/
%{_kf5_debugdir}/ktexteditor.categories
%{_kf5_debugdir}/*.renamecategories

%files devel
%{_kf5_libdir}/libKF5TextEditor.so
%{_kf5_libdir}/cmake/KF5TextEditor/
%{_kf5_includedir}/KTextEditor/
%dir %{_kf5_sharedir}/kdevappwizard
%dir %{_kf5_sharedir}/kdevappwizard/templates
%{_kf5_sharedir}/kdevappwizard/templates/ktexteditor-plugin.tar.bz2
%{_kf5_mkspecsdir}/qt_KTextEditor.pri

%changelog
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Remove code variants for building with Qt 6
  * completion: Fix only start chars of items are matched
  * Fix chaotic up/down cursor movement in Block Selection Mode
  * Fix backspace behavior for empty lines with cursor beyond line’s end (block selection mode)
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- Changes since 5.106.0:
  * Add missing includes
  * Fix incorrect lineHeight for drag pixmap (kde#468196)
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Fix Save Copy As.. not working anymore (kde#468672)
  * Fix indenting removes characters if line has tabs at start (kde#468495)
  * Printer: AlignVCenter line numbers
  * Dont ignore folding when printing code (kde#417138)
  * Use m_fontAscent instead of fm.ascent()
  * Draw caret ourselves (kde#172630)
  * Fix selection highlight for RTL text with custom line height (kde#464087)
  * Include range.js when initializing the engine (kde#456701)
  * Fix RTL text with format incorrectly shaped (kde#438755)
  * xml-indent: Optimize getCode
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- Changes since 5.104.0:
  * try to improve test stability
  * autoindent: fix indentation when "keep extra spaces" is enabled
  * Julia indent: fix indentation when "keep extra spaces" is enabled,
    also fix indentation when a line ends with a string assignment
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Improve cstyle performance
  * Improve performance of rendering spaces with dyn wrap disabled (kde#465841)
  * documentSaveCopyAs: Use async job api (kde#466571)
  * Optimize rendering spaces with dyn wrapping (kde#465841)
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * Fix indent failing due to unknown method 'replace'
  * Don't show selection count when there are none
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Add missing include
  * Fix crash on undo after reload (kde#462793)
  * Fix 1 space indent wrongly detected
  * Update the cursor and anchor to sync with the visual but not scroll for selectAll
  * Implement invokeAction and commit preedit when click outside the preedit.
  * Add missing KWindowSystem dependency
  * Fix 1 space indent not detected
  * Made suggested changes
  * Added New Script Sort Uniq
  * do some limited lookahead
  * ensure we emit the changes signal if needed
  * ensure proper range cleanup
  * do full update of the border
  * fix hl logic again
  * remove no longer used doHighlight params
  * remove flagFoldingStartIndentation
  * remove markedAsFoldingStartIndentation
  * avoid use of markedAsFoldingStart
  * start to compute indentation based folding on demand
  * Accept event when clearing multicursors
  * Add Dart and Go to katemoderc
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * Convert part metadata to JSON
  * Kate:TextLine: switch to std::shared_ptr
  * Fix setting default mark when ctrl is pressed
  * Fix caret with inline notes
  * Add "Character" the "Insert Tab" action name.
  * Fix condition for installing desktop file
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Too many changes since 5.99.0, only listing bugfixes:
  * CamelCursor: Improve complex unicode handling (kde#461239)
  * remove file name for saveas only for remote files (kde#461161)
  * Fix tab order in search (kde#440888)
  * fix clipboard selection update on shift mouse click (kde#443642)
  * Ensure to set highlight on reload when file type was set by user (kde#454715)
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Macro replaced by factory function
  * Small refactor to KateViewInternal::word{Prev,Next}
  * Tests for basic cursor movement between words
  * Remove shell-like completion handling on TAB
  * Allow code completion using the tab key
  * clipboardialog: add placerholder label when empty
  * Unassign transpose character shortcut
  * avoid magic to compute line (kde#450817)
  * Enable indent-on-paste for indenttest
  * Fix cstyle/indentpaste4 script
  * Fix cstyle tests: elsething and fork
  * Disable R indenter debug mode
  * Don't change indent-on-paste default yet
  * Add tests and fixes for R indent-on-paste
  * Add tests and fixes for julia indent-on-paste
  * Add tests for ruby indent-on-paste
  * Add tests and fixes for python indent and indent-on-paste
  * Fix python indent script trigger character detection with empty chars
  * Disable cstyle.js debug mode
  * Add tests and fixes for cstyle indent and indent-on-paste
  * Enable 'indent text on paste' by default
  * Normalize signatures in mainwindow.cpp
  * Plugin template: fix install location
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Too many changes since 5.97.0, only listing bugfixes:
  * Fix toggle comment with empty line in selection (kde#458126)
  * Fix some inconsistencies in completion config tab (kde#443994)
  * Dont enforce word boundary with multicursor occurunce select (kde#457948)
  * Optionally allow to show EndOfLine type in statusbar (kde#457885)
  * allow to configure printing font (kde#457480)
  * Update folding ranges on text modification (kde#436480)
  * Ignore folding ranges if document has changed (kde#384459)
  * Fix vi mode delete behavior (kde#453964)
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * fix crash (kde#457392)
  * Pass parent widget to print preview dialog
  * fix crash in insertText
  * Make views for read-only themes read-only instead of disabling them
  * Cleanup: Remove unused members from KateStyleTreeWidget
  * Cleanup: use switch in defaultStyleName
  * Make defaultStyleCount reusable
  * Silence compiler warning when compiling without KAUTH
  * avoid crash on caret drawing if no view (kde#456508)
  * avoid accessing view pointer during printing (kde#456508)
  * remove unused library
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * AppCommands: Do not quit application when last document or all documents are closed (kde#454924)
  * Fix leak of KateCompletionWidget::m_argumentHintTree
  * Allow to disable KAuth
  * KateThemeConfig: when copying a scheme, put the current name in the line-edit
  * Utilize ECMDeprecationSettings to manage deprecate Qt API
  * avoid that saveAs uses filename as directory (kde#454648)
  * allow to disable the autoreload if content is in git
  * Fix occurence highlighting not working with custom line height
- Drop 0001-Disable-KAuth-integration.patch. Replaced by a CMake
  option (ENABLE_KAUTH)
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * Don't add empty dictionary to context menu
  * Fix Qt6 build issue about using QVector without template arg
  * Fix whitespace slider & group text related options
  * port to standard C++ smart pointers where possible
  * Ensure to keep special dictionary setting on replaced word
  * observe changes on textChanged for QSpinBox (kde#453978)
  * fix compile with Qt 6
  * fix comments & add since 5.95 info
  * export multi cursors to JS
  * add multi cursor API
  * Add suggestion on top of context menu
  * Avoid calling slightly expensive contextMenu() twice
  * Check for empty selection too
  * Ensure next right click works properly if there was a selection
  * Protect replaceWordBySuggestion against segfault
  * Ugly hack to avoid segfault
  * Support to change dictionary on words and selections
  * Use only setVisible, remove SLOT attribute, avoid unneeded settings
  * Oops! Fix permanent active misspelled range after word selection
  * Add misspelled word to spell menu action
  * Remove unneeded set to nullptr
  * Make only once used member local
  * Properly support to fix selected words by spell check
  * Move spellcheck entry in context menu on top
  * Don't track mouse move for spellcheking
  * Add an action to remove cursors from empty lines
  * Add more tests for setCursors and setSelections
  * Refactor multicursor methods
  * Make multicursor test methods static
  * Add methods to set/get cursors and selections
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Too many changes since 5.93.0, only listing bugfixes:
  * avoid cursor move on insert of line at EOF on save (kde#453252)
  * Fix crash when ModeMenuList wasn't init but we try to reload it (kde#452282)
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Too many changes since 5.92.0, only listing bugfixes:
  * fix wrap of search for slash (kde#451893)
  * Improve cursor movement with RTL text in doc (kde#451789)
  * Add support for custom line height (kde#328837)
  * Fix cursor in RTL text with dyn wrap on (kde#385694, kde#368182)
  * Fix crash with stale indexes (kde#451593)
  * Disable multicursor in block selection mode (kde#451542)
  * Fix toggle comment with space at the start (kde#451471)
  * vimode: fix extra newline when using the "Find" action (kde#451076)
  * fix config dialog sizes for KTextEditor (kde#445541)
  * add new line on save inside the buffer (kde#450919)
- Rebase 0001-Disable-KAuth-integration.patch
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Too many changes since 5.91.0, only listing bugfixes:
  * vimode: implement hlsearch (kde#449641, kde#449643)
  * view: fix buggy scrolling on macOS (kde#442060)
  * Guard against null widgets (kde#450094)
  * use the url of the latest used document for save (kde#448618)
  * Differentiate docs with identical filenames (kde#381532)
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Too many changes since 5.90.0, only listing bugfixes:
  * KateModOnHdPrompt::slotDiff: Create diff file in temp folder (kde#448257)
  * avoid flicker for border on size changes (kde#435361)
  * When using tabs, use tabs to auto indent (kde#367966, kde#375529)
  * Don't scroll on select all (kde#435855)
  * Handle single statement condition blocks better (kde#385472)
  * Allow disabling focus frame (kde#418657)
  * Fix comment toggling when all lines in selection aren't commented (kde#426981)
  * Fix selection scrolling from line border works only downwards (kde#419076)
  * Fix camel cursor when last word is of one letter only (kde#448692)
  * Do proper fuzzy matching in completion (kde#401509)
  * Revert "Do not cancel mouse selection when using the keyboard" (kde#447525)
  * Restore undo history when document is same (kde#297883)
  * Fix drag pixmap highlight sometimes does not match original text (kde#438567)
  * Find: Update working range when replacing (kde#447972)
  * set QClipboard::Selection for select all (kde#428099)
  * Fix rash when switching between tabs while search is running (kde#445683)
  * improve wording for modified on disk warnings (kde#372638)
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Add a formatting commit to ignore-list
  * try to fix behavior for vimode on completion (kde#444883)
  * Change build system to make building against qt6
  * Apply word filter on async completion models (kde#444883)
  * Validates the input method attributes received from input method. (kde#443977)
  * fix compile on Mac if EditorConfig is found
  * Remove unused exporting of SwapFile class symbols
  * Fix cursor position after completion tail restore
  * let cmake generate the PCH header completely
  * Introduce PCH support
  * Color current indentation line differently
  * Fix unused capture warning
  * Vimode-keyparser: Make some functions more efficient
  * Use KTextEditor::Range by value
- Rebase 0001-Disable-KAuth-integration.patch
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Bring back git via QProcess
  * When reloading, don't override auto-detected hl mode if not set by user
  * If user didn't set them, don't override file type and highlighting modes detection
  * Pass KTextEditor::Cursor by value everywhere
  * Use const QString
  * Revert "completion: invoke always"
  * Remove selected text if preedit is not empty.
  * Disable "tail-available-on-undo" in ViInputMode
  * Fix vi-mode completion unit-tests
  * Improve built-in search performance
  * Remove duplicated lua.js indent file
  * Fix a compiler warning
  * Review KateTextLine usages
  * Create a separate path for fetching lineLength
  * Use iterators for iterating over blocks
  * Completion in two edits feature describing comment
  * Re-add "undo removed tail" on completion
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Too many changes since 5.87.0, only listing bugfixes:
  * Expand katepart metadata (kde#444714)
  * TextFolding::importFoldingRanges: get rid of UB (kde#444726)
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * The user is not selecting as soon as we clearSelection
  * fix missing i18n (kde#442071)
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Too many changes since 5.85.0, only listing bugfixes:
  * Python indentation: decrease indent when appropriate keyword is typed (kde#392732)
  * Do not show encoding error when file only contains BOM (kde#440359)
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Remove module prefix of include
  * Network mounts performance optimizations
  * KateView: speed up large view jumps
  * Fix apidox for class Mark
  * better comments
  * ensure close button on top for replace
  * move close button to right for bottom widgets
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Too many changes since 5.83.0, only listing bugfixes:
  * WIP: Take into account wordCompletionRemoveTail in
    completionRange() default implementation (kde#436170)
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Too many changes since 5.82.0, only listing bugfixes:
  * Limit shortcut context to active view for Reuse Word Above/Below (kde#352902)
  * Add "Transpose Words" feature (kde#436621)
  * Fix on-the-fly spell checking with recent Qt (kde#436004)
  * Revert "Add option to keep spaces to the left of cursor when
    saving" (kde#433455)
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Too many changes since 5.81.0, only listing bugfixes:
  * Fix dragging when folding stuff is around (kde#435500)
  * Fix incremental selection-only search (kde#327408)
  * Attempt fix crash on dragging (kde#435500)
  * fix memory corruption on 'Close the file, discard..' (kde#433180)
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Too many changes since 5.80.0, only listing bugfixes:
  * Don't warn about unsaved changes when closing if blank and unsaved (kde#391208)
  * Use QPalette::highlight for the scrollbar minimap slider (kde#434690)
  * Restrict horizontal range of cursor to avoid unintentionally wrapping. (kde#423253)
  * Add option to keep spaces to the left of cursor when saving (kde#433455)
  * fix unit tests => don't remove trailing spaces (kde#434163)
  * fix spellcheck word detection for non-ASCII (kde#433673)
  * fix auto-completion for non ASCII words (kde#433672)
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Too many changes since 5.79.0, only listing bugfixes:
  * use correct function to determine with of line number characters (kde#430712)
  * Add option to preselect nothing when automatic completion is invoked (kde#316413)
  * Temporarily save unfinished search/replace text (kde#411923)
  * avoid crash on clearing of bookmarks (kde#433006)
  * [Vimode] Do not remove empty lines when reformatting (kde#340550)
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Too many changes since 5.78.0, only listing bugfixes:
  * [Vimode] Do not switch view when changing case (~ command) (kde#432056)
  * Increase maximum indentation width to 200 (kde#432283)
  * Only show bookmark chars error when in vimode (kde#424172)
  * Retain replacement text as long as the power search bar is not closed (kde#338111)
  * Allow "Dynamic Word Wrap Align Indent" to be disabled (kde#430987)
  * [Vimode]Fix search inside fold ranges (kde#376934)
  * [Vimode] Fix Macro Completion Replay (kde#334032)
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Too many changes since 5.77.0, only listing bugfixes:
  * Show the dragged text when dragging (kde#398719)
  * Undo indent in one step (kde#373009)
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Port KComboBox to QComboBox
  * use KSyntaxHighlighting themeForPalette
  * fix i18n call, missing argument (kde#429096)
  * minor improvements to theme search
  * Improve the automatic theme selection
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Too many changes to list here.
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Too many changes to list here.
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Too many changes to list here.
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
  * add icons to all buttons of file modified message (kde#423061)
  * Revert changes in autotests. It seems that camelcase changes breaks them
  * Use camelcase include. (scripted)
  * Use the canonical docs.kde.org URLs
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Make "goto line" work backwards (kde#411165)
  * fix crash on view deletion if ranges are still alive (kde#422546)
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Add .diff to the file-changed-diff to enable mime detection on windows.
  * scrollbar minimap: performance: delay update for inactive documents
  * Make text always align with font base line
  * Port from KRun::runUrl to OpenUrlJob
  * Fix modified line marker in kate minimap
  * Port to KIO::statDetails. We only need StatBasic since we only need the permissions
* Fri May 15 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 5.70.1
  * Revert "Store and fetch complete view config in and from
    session config" (kde#421375)
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * fix drag'n'drop on left side border widget (kde#420048)
  * Revert premature port to unreleased Qt 5.15
  * Store and fetch complete view config in and from session config
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * Make it compile against q5.15 (QString:: is deprecated)
  * Add missing include
  * fix folding crash for folding of single line folds (kde#417890)
  * fix unit test
  * [VIM Mode] Add g<up> g<down> commands (kde#418486)
  * Add MarkInterfaceV2, to s/QPixmap/QIcon/g for symbols of marks
  * Draw inlineNotes after drawing word wrap marker
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * templates: Convert license statements to SPDX headers
  * Remove duplicate include
  * README.md: fix example code & code markup
  * Fix minor EBN issues (http->https)
  * Make it compile against last qt5.15 without deprecated method. QOverload<int>::of(&QComboBox::currentIndexChanged) is deprecated
  * Add an option to dynamic-break inside words
  * Use ecm_qt_install_logging_categories over manual categories file
  * KateModeMenuList: don't overlap the scroll bar
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Too many changes since 5.66.0, only listing bugfixes:
  * fix Drag&copy function (by using Ctrl Key) (kde#413848)
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Fix warning about unused variable and minor optimization
  * Add "line-count" property to the ConfigInterface
  * Avoid unwanted horizontal scrolling (kde#415096)
  * Port deprecated QSet::toList() method
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * KateModeManager::updateFileType(): validate modes and reload menu of the status bar
  * Remove unused include
  * Remove KIconThemes use
  * Verify modes of the session config file
  * LGPLv2+ after ok by Svyatoslav Kuzmich
  * restore files pre-format
  * don't touch templates/
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Too many changes since 5.63.0, only listing bugfixes:
  * fix crash (kde#413474)
  * add missing s (kde#413158)
- Drop 0001-fix-crash-in-variableexpansionhelpers.patch. Merged upstream.
* Wed Oct 30 2019 Antonio Larrosa <alarrosa@suse.com>
- Add 0001-fix-crash-in-variableexpansionhelpers.patch to fix a crash
  when adding a variable to swap file name (kde#413474)
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Too many changes since 5.62.0, only listing bugfixes:
  * QRectF instead of QRect solves clipping issues, even thought the rectangle has pure integer coordinates/sizes (kde#390451)
  * Add keyboard shortcut for switching Input modes to edit menu (kde#400486)
  * Backup on save: Support time and date string replacements (kde#403583)
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Allow to customize attributes for KSyntaxHighligting themes
  * More port away from Qt's foreach all loops over method-local containers
  * Port away from Qt's foreach all loops over rvalue container objects
  * Port away from Qt's foreach all loops over method-local containers
  * Fix for all themes: allow turn off attributes in XML highlighting files
  * play in unit test with better searchText implementation
  * fix build when using Qt 5.11
  * simplify isAcceptableInput + allow all stuff for input methods
  * simplify typeChars, no need for return code without filtering
  * Mimic QInputControl::isAcceptableInput() when filtering typed characters (kde#396764)
  * try to sanitize line endings on paste (kde#410951)
  * Fix: allow turn off attributes in XML highlighting files
  * improve word completion to use highlighting to detect word boundaries (kde#360340)
  * More porting from QRegExp to QRegularExpression
  * properly check if diff command can be started for swap file diffing (kde#389639)
  * KTextEditor: Fix left border flicker when switching between documents
  * Migrate some more QRegExps to QRegularExpression
  * Add .clangd to .gitignore list
  * fix vi mode unit test
  * Allow 0 in line ranges in vim mode.
  * Use CMake find_dependency instead of find_package in CMake config file template.
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Save and load page margins
  * Don't persist authentication
  * Re-map default "Switch input mode" shortcut to not confict with konsolepart (kde#409978)
  * Make keyword completion model return HideListIfAutomaticInvocation by default
  * Minimap: Do not grab the left-mmouse-button-click on up/down buttons
  * Fix minor typos
  * allow up to 1024 hl ranges instead of not higlighting the line at all if that limit is reached
  * fix folding of lines with end position at column 0 of a line (kde#405197)
  * move enum to dialog, only used there
  * Add option to treat some chars also as "auto bracket" only when we have a selection
  * Add an action to insert a non-indented newline (kde#314395)
  * Add setting to enable/disable text drag-and-drop (on by default)
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop conditionals for no longer supported distribution versions
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * fix goto line centering force center for any external set cursor position call (kde#408418)
  * Fix bookmark icon display on icon border with low dpi
  * Fix action "Show Icon Border" to toggle border again
  * Remove ifdef for Qt 5.11 since we require that version now
  * Fix compiler warning about unused variable
  * Fix empty pages in print preview and lines printed twice (kde#348598)
  * remove no longer used header
  * fix unit test for all operating systems
  * fix unit test
  * fix autoscrolling down speed (kde#408874)
  * Add default variables for variables interface
  * Make automatic spellcheck work after reloading a document (kde#408291)
  * raise default line length limit to 10000
  * WIP:Disable highlighting after 512 characters on a line.
  * KateModeMenuList: move to QListView
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Don't delete entire previous line by backspace in pos 0 (kde#408016)
  * Use native dialog overwrite check
  * Review del/backspace
  * Add action to reset font size
  * show static word wrap marker always if requested
  * Ensure highlighted range begin/end marker after unfold
  * Fix: don't reset Highlight when saving some files (kde#407763)
  * Auto indentation: Use std::vector instead of QList
  * Fix: Use default indentation mode for new files
  * remove duplicated assignment
  * honor auto-bracket setting for balance check
  * improve invalid character check on loading (kde#406571)
  * New menu of syntax highlighting in the status bar
  * Avoid infinite loop in "Toggle Contained Nodes" action
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Too many changes to list here
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Too many changes to list here
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Remove override keyword
  * Use isEmpty here
  * Remove deprecated method
  * try to improve painting height for text lines - bug 403868 avoid to cut _
    and other parts still broken: double height things  like mixed
    english/arab, see bug 404713 (kde#403868)
  * Use QTextFormat::TextUnderlineStyle instead of QTextFormat::FontUnderline (kde#399278)
  * Make it possible to show all spaces in the document (kde#381267, kde#342811)
  * Do not print indent lines
  * KateSearchBar: Show also search has wrapped hint in nextMatchForSelection() aka Ctrl-H
  * katetextbuffer: refactor TextBuffer::save() to better separate code paths
  * Use AuthCore instead of Auth
  * Remove dead code
  * Explicitly link against KAuth
  * Refactor KateViewInternal::mouseDoubleClickEvent(QMouseEvent *e)
  * Improvements to completion
  * Add TODO KF6 note
  * Set the color scheme to Printing for Print Preview (kde#391678)
- Refreshed patches:
  * 0001-Disable-KAuth-integration.patch
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * skip cppstyle indentation test for !t 5.12.0 which has a broken regex implementation in JS
  * KateSpellCheckDialog: Remove action "Spellcheck Selection"
  * Update JavaScript library underscore.js to version 1.9.1
  * Fix bug 403422: Allow changing the marker size again (kde#403422)
  * Consistently use override, not Q_DECL_OVERRIDE
  * SearchBar: Add Cancel button to stop long running tasks
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of ECM_MODULE_PATH
  * Review KateGotoBar
  * ViewInternal: Fix 'Go to matching bracket' in override mode
  * Delete copy constructor and assignment operator from public vim/ classes
  * delete copy constructor and assignment operator of some internal classes
  * Use HTTPS, if available, in links visible to users
  * Review KateStatusBar
  * ViewConfig: Add option to paste at cursor position by mouse (kde#363492)
  * Use the nicer K_PLUGIN_CLASS_WITH_JSON
  * Remove Qt version check
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix unit test that arbitrarily fails
  * fix scripting for Qt 5.12
  * Fix emmet script by using HEX instead of OCT numbers in strings (kde#386151)
  * Fix broken Emmet (kde#386151)
  * ViewConfig: Add 'Dynamic Wrap At Static Marker' option
  * fix folding region end, add ending token to the range
  * avoid ugly overpainting with alpha
  * Don't re-mark words added/ignored to the dictionary as misspelled (kde#387729)
  * KTextEditor: Add action for static word wrap (kde#141946)
  * ViewPrivate: Don't hide 'Clear Dictionary Ranges' action
  * KateStatusBar: Reformatted by astyle command to follow coding style
  * Don't ask for confimation when reloading (kde#401376)
  * class Message: Use inclass member initialization
  * KTextEditor::Message: Review documentation
  * use STL were no implicit sharing is required
  * Expose KTextEditor::ViewPrivate:setInputMode(InputMode) to KTextEditor::View
  * improve range handling, no allocations for common updates (kde#333517)
  * KateViewInternal: Rename getMouse/Cursor() => mouse/cursorPosition() to fit coding style
  * tune editing actions for large number of small edits
  * Only cal updateView() in visibleRange() when endPos() is invalid.
  * KateViewInternal: S&R
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * KTextEditor::ViewPrivate: S&R
  * KateViewInternal: Remove unneeded functions
  * Allow negative syntax definition priorities.
  * Expose "Toggle Comment" feature through tools menu and default shortcut (kde#387654)
  * Fix hidden languages in the mode menu
  * SpellCheckBar: Use DictionaryComboBox instead of plain QComboBox
  * KTextEditor::ViewPrivate: Avoid warning "Text requested for invalid range"
  * Android: No need to define log2 anymore
  * disconnect contextmenu from all aboutToXXContextMenu receivers (kde#401069)
  * Introduce AbstractAnnotationItemDelegate for more control by consumer
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Remove unused variables
  * Fix minor EBN issues and typos
  * Fix align of doxygen comments in templates
  * Use normalized signatures with SIGNAL(), SLOT(), Q_ARG(), Q_RETURN_ARG()
  * Remove duplicated includes
  * Use more explicit constructors with internal classes
  * Remove double underscore (__) from header include guards
  * Minor: Cleanup some code
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Restaure default severity
  * Autogenerate debug file + create categories file
  * Port to no deprecated method
  * Paint code folding marker only for multiline code folding regions
  * Intialize m_lastPosition
  * Scripting: isCode() returns false for dsAlert text
  * fix ebn issues
  * use R Script hl for R indent tests
  * Unit tests for the R indent script
  * Update of the R indent script
  * Fix Solarized Light and Dark color schemes (kde#382075)
  * Don't require Qt5::XmlPatterns
* Mon Sep 17 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Too many changes to list here
- Refreshed patches:
  * 0001-Disable-KAuth-integration.patch
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * proper fix for the raw string indenting auto-quoting
  * fix indenter to cope with new syntax file in syntaxhighlighting framework
  * adjust test to new state in syntax-highlighting repository
  * Show "Search wrapped" message in center of view for better visibility
  * fix warning, just use isNull()
  * Extend Scripting API
  * fix segfault on rare cases where empty vector occurs for word count happens e.g. sometimes for vimode_emulatedcommandbar test
  * enforce clear of scrollbar preview on document clear BUG: 374630 (kde#374630)
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * use nullptr, not 0
  * add missing const qualifiers
  * guard updateConfig for disabled status bars
  * add context menu to statusbar to toggle show total lines/word count
  * Implemented displaying of total lines in kate (kde#387362)
  * Make menu-bearing toolbar buttons show their menus with normal click rather than click-and-hold (kde#353747)
  * CVE-2018-10361: privilege escalation
  * Fix caret width (kde#391518)
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Warning--
  * Use override
  * Don't use title case for the "show word count" checkbox
  * Make the word/char count a global preference
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * optimization of KTextEditor::DocumentPrivate::views()
  * [ktexteditor] much faster positionFromCursor
  * Implement single click on line number to select line of text
  * Warning--
  * Add missing override
  * Fix problem that font/italic/... attributes no longer work with e.g. >= Qt 5.9
  * clang-tidy: modernize-use-default-member-init run
- Dropped patches, now upstream:
  * Fix-font-attributes.patch
* Wed Apr 18 2018 wbauer@tmo.at
- Add Fix-font-attributes.patch to fix missing bold/italic/...
  markup with modern Qt versions (>= 5.9)
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Make it possible for KTextEditor to build on Android NDK's gcc 4.9
  * avoid Asan runtime error: shift exponent -1 is negative
  * We depend against 5.8.0
  * optimization of TextLineData::attribute
  * Don't calculate attribute() twice.
  * Revert Fix: View jumps when Scroll past end of document is enabled (kde#391838)
  * don't pollute the clipboard history with dupes
  * Revert "[KateCompletionWidget] Create configuration interface on demand" (kde#391955)
  * [KateCompletionWidget] Create configuration interface on demand
  * Remove not necessary QtCore and co
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Initialize value
  * Iterate over initializer_lists to avoid mem allocs
  * Add icons for KTextEditor Document-Export, Bookmark-Remove and Formatting Text Upppercase, Lowercase and Capitalize
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * improve line heigh computation try to avoid cutting of parts of glyphs
  * Fix: View jumps when Scroll past end of document is enabled (kde#306745)
  * KateView unit test: simplify finding KateViewInternal
  * Use at least the requested width for the argument hint tree
  * ExpandingWidgetModel: find the right-most column based on location
  * Simplify code: return early to reduce indentation depth
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * clang-tidy modernize-use-override
  * Fix wildcard matching for modelines
  * Fix Unit Test
  * Fix compilation
  * Fix a regression caused by changing backspace key behavior
  * port to non-deprecated API like already used at other place (kde#386823)
  * Add missing include for std::array
  * MessageInterface: Add CenterInView as additional position
  * Verify if QTest::qWaitForWindowExposed returns true
  * QStringList initializer list cleanup
  * Migrate some QRegExps to QRegularExpression
  * Fix warning about unused variable
  * Fix syntax unit tests
  * Fix API documentation about RangeCommand
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Use directly QStringLiteral
  * We depend against 5.7
  * API dox: fix section id
  * Plugin template: remove bogus translation strings
  * Fix VI-Mode buffer commands
  * Remove unused member variable
  * prevent accidental zooming.
  * autotests: Remove dep on Qt5::Script again
  * Fix: Missing dependencies for ktexeditor autotests
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * API dox: fix wrong names of methods and args, add missing \since
  * Avoid (certain) crashes while executing QML scripts (kde#385413)
  * Avoid a QML crash triggered by C style indentation scripts
  * - Increase size of trailing mark
  * add autotests for D8333
  * fix some indenters from indenting on random characters
  * Fix deprecation warning
- Remove patches, now upstream:
  * fix-some-indenters-from-indenting-on-random-characters.patch
* Tue Oct 24 2017 wbauer@tmo.at
- Add fix-some-indenters-from-indenting-on-random-characters.patch
  to fix broken indentation of some languages (e.g. Python)
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Ignore default mark in icon border for single selectable mark
  * Minor spell check interface fixes
  * Use QActionGroup for input mode selection
  * Fix missing spell check bar (kde#359682)
  * Fix the fall-back "blackness" value for unicode > 255 characters. (kde#385336)
  * Plugin template: fix name of Messages.sh
  * Fix trailing space visualization for RTL lines.
  * fix typo approved by Dominik Haumann
* Wed Sep 13 2017 lbeltrame@kde.org
- Add 0001-Disable-KAuth-integration.patch
  * Streamlined way to disable KAuth support from ktexteditor
- Remove patches, folded into the above:
  * 0001-Revert-KAuth-integration-in-document-saving-vol.-2.patch
  * 0002-Revert-KAuth-integration-in-document-saving.patch
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Port Document/View scripting API to QJSValue-based solution
  * Show icons in icon border context menu
  * Use config.h more
  * Fix compilation on windows with editorconfig-c-core available
  * Replace KStandardAction::PasteText with KStandardAction::Paste
  * Support fractional scaling in generating the sidebar preview
  * Fix build with QT_NO_ACCESSIBILITY
  * Switch from QtScript to QtQml
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Handle fine-grained wheel event in zooming
  * Add template for a ktexteditor plugin
  * Add KF6 TODO for missing argument namespace in slot signature
  * copy permissions from original file on save copy BUG: 377373 (kde#377373)
  * perhaps avoid stringbuild crash BUG: 339627 (kde#339627)
  * fix problem with * adding for lines outside of comments BUG: 360456 (kde#360456)
  * fix save as copy, it missed to allow overwriting the destination file we check
    if we want that via a dialog, but we still always fail to do so BUG: 368145 (kde#368145)
  * Adapt unit test to changes from KSyntaxHighlighting framework
  * Command 'set-highlight': Join args with space
  * fix crash on view destruction because of non-deterministic cleanup of objects
  * Emit signals from icon border when no mark was clicked
  * Fix crash in vi input mode (sequence: "o" "Esc" "O" "Esc" ".") (kde#377852)
  * Use mutually exclusive group in Default Mark Type
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Fix cpu usage spiking after showing vi command bar (kde#376504)
  * Fix jumpy scrollbar-dragging when mini-map is enabled.
  * Jump to the clicked scrollbar position when minim-map is enabled. (kde#368589)
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Add Q_FALLTHROUGH
  * Add missing break
  * Unbreak KateSyntaxTest in paths with dots, check only dir entry name for .
  * Revert "Add temporary debug output for investigating KateSyntaxTest fail on CI"
  * Add temporary debug output for investigating KateSyntaxTest fail on CI
  * Remove duplicated path separator
  * Unbreak autotests in paths with spaces, properly escape " chars
  * Use explicit flag values or explicit constructor instead of nullptr
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * KAuth integration in document saving - vol. 2 - various security improvements
  * Fix assertion when applying code folding that changes cursor position
  * Use non-deprecated <gui> root element in ui.rc file
  * Add scroll-bar-marks also to the built-in search&replace
  * KAuth integration in document saving
- Revert upstream feature as disliked by the security team (boo#1033055)
  * 0001-Revert-KAuth-integration-in-document-saving-vol.-2.patch
  * 0002-Revert-KAuth-integration-in-document-saving.patch
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * fix debug warning (and wrong pen value) found by kfunk, introduced my me
  * Expose additional internal View's functionality to the public API
  * Upgrade KF5 version to 5.33.0.
  * save a lot of allocation for setPen
  * Fix ConfigInterface of KTextEditor::Document
  * Add unit test for KTextEditor::ConfigInterface
  * Added font and on-the-fly-spellcheck options in ConfigInterface
* Sat Apr  8 2017 fabian@ritter-vogt.de
- Enable editorconfig support only on TW and Leap >= 42.2
* Sat Mar 25 2017 fabian@ritter-vogt.de
- Enable editorconfig support
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Fix compilation with Qt 5.6
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Remember file type set by user over sessions
  * Reset filetype when opening url
  * Added getter for word-count configuration value
  * vimode_completion unit test failure
  * Consistent conversion from/to cursor to/from coordinates
  * Update file type on save only if path changes
  * EditorConfig support
  * add FindEditorConfig to ktexteditor if that proves to be useful, can be moved to extra-cmake-modules, thought I see its use is rather specialized to ktexteditor
  * Fix: emmetToggleComment action doesn't work
  * Use sentence style capitalization with label texts of edit fields
  * Reverse meaning of :split, :vsplit to match vi and Kate actions.
  * Use C++11 log2() instead of log() / log(2)
  * KateSaveConfigTab: put spacer behind last group on Advanced tab, not inside
  * KateSaveConfigTab: Remove wrong margin around content of Advanced tab
  * Borders config subpage: fix scrollbar visibility combobox being off-placed
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Prevent Qt warnings about an unsupported clipboard mode on Mac
  * Use syntax definitions from KF5::SyntaxHighlighting
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Breeze Dark: Darken current-line background color for
    better readability (kde#371042)
  * Sorted Dockerfile instructions
  * Breeze (Dark): Make comments a bit lighter for
    better readability (kde#371042)
  * Fix CStyle and C++/boost indenters when automatic
    brackets enabled (kde#370715)
  * Add modeline 'auto-brackets'
  * Fix inserting text after end of file (rare case)
  * Fix invalid xml highlighting files
  * Maxima: Remove hard-coded colors, fix itemData Label
  * Add OBJ, PLY and STL syntax definitions
  * Add syntax highlighting support for Praat
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * XML files: remove hard-coded color for values
  * XML: Remove hard-coded color for values
  * XML Schema Definition: Turn 'version' into an xs:integer
  * Highlighting definition files: round version up to next integer
  * Support multi char captures only in {xxx} to avoid regressions
  * Support regular expressions replaces with captures > \9, e.g. I
    (kde#365124)
  * Fix rendering of characters spanning into next line,
    e.g. underlines are no longer cut off with some fonts/font-sizes
    (kde#335079)
  * Fix crash: Make sure the display cursor is valid after text folding
    (kde#367466)
  * KateNormalInputMode needs to rerun SearchBar enter methods
  * try to "fixup" rendering of underlines and stuff like that
    (kde#335079)
  * Show "View Difference" button only, if 'diff' is installed
  * Use non-modal message widget for externally
    modified file notifications (kde#353712)
  * Fix regression: testNormal did only work because of
    test execution at once
  * Split the indent test into separate runs
  * Support "Unfold Toplevel Nodes" action again (kde#335590)
  * Fix crash when showing top or bottom messages multiple times
  * Fix eol setting in mode lines (kde#365705)
  * Highlight .nix files as bash, guess can't hurt (kde#365006)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Remove accel clash (kde#363738)
  * Fix email address highlighting in doxygen (kde#363186)
  * Detect some more json files, like our own projects ;)
  * Improve mime-type detection (kde#357902)
  * Bug 363280 - highlighting: c++: #if 1 #endif #if defined (A) aaa
    [#]elif defined (B) bbb #endif (kde#363280)
  * Bug 351496 - Python folding is not working during initial typing
    (kde#351496)
  * Bug 365171 - Python syntax highlighting: not working correctly
    for escape sequences (kde#365171)
  * Bug 344276 - php nowdoc not folded correctly (kde#344276)
  * Bug 359613 - Some CSS3 properties are not supported in
    syntax highlight (kde#359613)
  * Bug 367821 - wineHQ syntax: The section in a reg file isn't
    highlighted correctly (kde#367821)
  * Improve swap file handling if swap directory specified
  * Fix crash when reloading documents with auto-wrapped line due
    to line length limit (kde#366493)
  * Fix constant crashes related to the vi command bar
    (kde#367786)
  * Fix: Line numbers in printed documents now starts at 1
    (kde#366579)
  * Backup Remote Files: Treat mounted files also as remote files
  * Cleanup logic for searchbar creation
  * Add highlighting for Magma
  * Allows only one level of recursion
  * Fix broken swap-file on windows
  * Patch: add bitbake support for syntax highlighting engine
  * Autobrace: look at spellcheck attribute where the character
    was entered (kde#367539)
  * Highlight QMAKE_CFLAGS
  * Don't pop out of the main context
  * Add some executable names that are commonly used
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Do not ask for overwriting a file twice with native dialogs
  * Added FASTQ syntax
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Show Scrollbar Text Preview after a delay of 250ms
  * Hide preview and stuff on view content scrolling
  * Set parent + toolview, I think this is needed to avoid task
    switcher entry in Win10
  * Remove "KDE-Standard" from encoding box
  * Folding preview on per default
  * Avoid dashed underline for preview & avoid poisoning of
    line layout cache
  * Always enable "Show preview of folded text" option
  * TextPreview: Adjust the grooveRect-height when
    scrollPastEnd is enabled
  * Scrollbar preview: use groove rect if scrollbar does
    not use full height
  * Add KTE::MovingRange::numberOfLines() just like KTE::Range has
  * Code folding preview: set popup height so that
    all hidden lines fit
  * Add option to disable preview of folded text
  * Add modeline 'folding-preview' of type bool
  * View ConfigInterface: support 'folding-preview' of type bool
  * Add bool KateViewConfig::foldingPreview() and
    setFoldingPreview(bool)
  * Feature: Show text preview when hovering over folded code block
  * KateTextPreview: add setShowFoldedLines() and showFoldedLines()
  * Add modelines 'scrollbar-minimap' [bool], and
    'scrollbar-preview' [bool]
  * Enable mini-map scrollbar by default
  * New feature: Show text preview when hovering over the scrollbar
  * KateUndoGroup::editEnd(): pass KTE::Range by const ref
  * Fix vim-mode shortcut handling,
    after behaviour changes in Qt 5.5 (kde#353332)
  * Autobrace: don't insert ' character in text
  * ConfigInterface: add scrollbar-minimap config key to
    enable/disable scrollbar mini map
  * Fix KTE::View::cursorToCoordinate() when top message widget
    is visible
  * Refactoring of the Emulated Command Bar
  * Fix drawing artifacts when scrolling while notifications
    are visible (kde#363220)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Fix default encoding to UTF-8 (kde#62604)
  * Fix color configurability of default style "Error"
  * Search & Replace: Fix replace background color (regression
    introduced in v5.22) (kde#63441)
  * New color scheme "Breeze Dark", see https://kate-editor.org/?post=3745
  * KateUndoManager::setUndoRedoCursorOfLastGroup(): pass Cursor
    as const reference
  * sql-postgresql.xml improve syntax highlighting by
    ignoring multiline function bodies
  * Add syntax highlighting for Elixir and Kotlin
  * VHDL syntax highlighting in ktexteditor: add support for
    functions inside architecture statements
  * vimode: Don't crash when given a range for a nonexistent
    command (kde#60418)
  * Properly remove composed characters when using Indic locales
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Use proper char syntax '"' instead of '\"'
  * doxygen.xml: Use default style dsAnnotation for "Custom Tags"
    as well (less hard-coded colors)
  * Add option to show the counter of words
  * Improved foreground color contrast for search & replace
    highlightings
  * Fix crash when closing Kate through dbus while the print
    dialog is open (kde##356813)
  * Cursor::isValid(): add note about isValidTextPosition()
  * Add API {Cursor, Range}::{toString, static fromString}
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Revert "Open/Save config page: Use term "Folder" instead
    of "Directory""
  * Open/Save config page: Use term "Folder" instead of "Directory"
  * kateschemaconfig.cpp: use correct filters with open/save dialogs
    (kde#343327)
  * c.xml: use default style for control flow keywords
  * isocpp.xml: use default style "dsControlFlow" for control
    flow keywords
  * c/isocpp: add more C standard types
  * KateRenderer::lineHeight() returns an int
  * printing: use font size from selected printing schema
    (kde#356110)
  * cmake.xml speedup: Use WordDetect instead of RegExpr
  * Change tab with to 4 instead of 8
  * Fix changing the current line number color
  * Fix selecting completion item with the mouse (kde#307052)
  * Add syntax highlighting for gcode
  * Fix the MiniMap selection background painting
  * Fix encoding for gap.xml (use UTF-8)
  * Fix nested comment blocks (kde#358692)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
- Drop upstreamed 0001-Fix-Clazy-fix-mistake-that-broke-selection-handling-.patch
* Sun Mar 27 2016 hrvoje.senjan@gmail.com
- Added 0001-Fix-Clazy-fix-mistake-that-broke-selection-handling-.patch
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Fix highlighting of all occurences in ReadOnlyPart
  * Don't iterate over a QString as if it was a QStringList
  * Properly initialize static QMaps
  * Prefer toDisplayString(QUrl::PreferLocalFile)
  * Support surrogate character sending from input method
  * Do not crash on shutdown when text animation is still running
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Better behaviour for "insert braces around" autobrace feature
  * Change option key to enforce new default,
    Newline at End of File = true
  * Remove some suspicious setUpdatesEnabled calls (kde#353088)
  * Delay emitting of verticalScrollPositionChanged until all stuff
    is consistent for folding (kde#342512)
  * Patch updating tag substitution (kde#330634)
  * Only update the palette once for the change event
    belonging to qApp (kde#358526)
  * Append newlines at EOF by default
  * Add NSIS syntax highlighting file
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Syntax h/l for pli: builtin functions added, expandable regions added
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Add syntax highlighting for TaskJuggler and PL/I
  * Make it possible to disable keyword-completion via
    the config interface.
  * Resize the tree when the completion model got reset.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * highlighting: gnuplot: add .plt extension
  * fix validation hint, add hint about the compile time validation
  * Don't crash when command is not available.
  * Fix kde##307107
  * Haskell highlighting variables starting with _
  * simplify git2 init, given we require recent enough version
    (kde#353947)
  * bundle default configs in resource
  * syntax highlighting (d-g): use default styles instead of
    hard-coded colors
  * better scripts search, first user local stuff, then the stuff
    in our resources, then all other stuff, that way the user can
    overwrite our shipped scripts with local ones
  * package all js stuff in resources, too, only 3 config files
    missing and ktexteditor could be just used as a library without
    any bundled files
  * next try: put all bundled xml syntax files into a resource
  * add input mode switch shortcut (kde#347769)
  * bundle xml files in resource
  * syntax highlighting (a-c): migrate to new default styles, remove
    hard-coded colors
  * syntax highlighting: remove hard-coded colors and use
    default styles instead
  * syntax highlighting: use new default styles
    (removes hard-coded colors)
  * Better "Import" default style
  * Introduce "Save As with Encoding" to save a file with different
    encoding, using the nice grouped encoding menu we have and
    replacing all save dialogs with the correct ones of the
    operating system without loosing this important feature.
  * bundle ui file into lib, using my extension to xmlgui
  * Printing again honors the selected font & color schema
    (kde#344976)
  * Use breeze colors for saved and modified lines
  * Improved icon border default colors of scheme "Normal"
  * autobrace: only insert brace when next letter is empty or
    not alphanumeric
  * autobrace: if removing start parenthesis with backspace,
    remove end as well
  * autobrace: only establish connection once
  * Autobrace: eat closing parentheses under some conditions
  * Fix shortcutoverride not being forwarded to the mainwindow
  * Bug 342659 - Default "bracket highlighting" color is hard to see
    (Normal schema fixed) (kde#342659)
  * Add proper default colors for "Current Line Number" color
  * bracket matching & auto-brackets: share code
  * bracket matching: guard against negative maxLines
  * bracket matching: just because the new range matches the old
    doesn't mean no update is required
  * Add the width of half a space to allow painting the cursor at EOL
  * fix some HiDPI issues in the icon border
  * fix kde##310712: remove trailing spaces also on line with cursor
    (kde#310712)
  * only display "mark set" message when vi input mode is active
  * remove & from button text (kde#345937)
  * fix update of current line number color (kde#340363)
  * implement brackets insert on writing a bracket over a selection
    (kde#350317)
  * auto brackets (kde#350317)
  * fix alert HL (kde#344442)
  * no column scrolling with dyn word wrap on
  * remember if highlighting was set by user over sessions to not
    loose it on save after restore (kde#332605)
  * fix folding for tex (kde#328348)
  * fixed kde##327842: End of C-style comment is misdetected (kde#327842)
  * save/restore dyn word wrap on session save/restore (kde#284250)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Validate more regexp
  * Fix regexps in HL files (kde#352662)
  * Sync ocaml HL with state of
    https://code.google.com/p/vincent-hugot-projects/
    before google code is down, some small bugfixes
  * Add word-break (kde#352258)
  * Validate line before calling folding stuff (kde#339894)
  * Fix Kate word count issues by listening to DocumentPrivate
    instead of Document (kde#353258)
  * Update Kconfig syntax highlighting: add new operators from Linux 4.2
  * Sync w/ KDE/4.14 kate branch
  * Minimap: Fix scrollbar handle not being drawn with
    scrollmarks off. (kde#352641)
  * Syntax: Add git-user option for kdesrc-buildrc
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Merge allocation of TextLineData and ref count block.
  * Change default keyboard shortcut for "go to previous editing line"
  * Syntax highlighting Haskell comment fixes
  * Speed up code-completion pop-up appearance
  * minimap: Attempt to improve the look and feel (kde#309553)
  * nested comments in Haskell syntax highlighting
  * Fix problem with wrong unindent for python (kde#351190)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Guard default log level for Qt < 5.4.0, fix log cat name
  * Add hl for Xonotic (kde#342265)
  * Add Groovy HL (kde#329320)
  * Update J highlighting (kde#346386)
  * Make compile with MSVC2015
  * Less iconloader use, fix more pixelated icons
  * Enable/disable find all button on pattern changes
  * Improved search & replace bar
  * Remove useless ruler from powermode
  * More slim search bar
  * vi: Fix misreading of markType01 flag
  * Use correct qualification to call base method.
  * Remove checks, QMetaObject::invokeMethod guards itself
    against that already.
  * Fix HiDPI issues with color pickers
  * Cleanup coe: QMetaObject::invokeMethod is nullptr safe.
  * More comments
  * Change the way the interfaces are null safe
  * Only output warnings and above per default
  * Remove todos from the past
  * Use QVarLengthArray to save the temporary QVector iteration.
  * Move the hack to indent group labels to construction time.
  * Fixup some serious issues with the KateCompletionModel in
    tree mode.
  * Fix broken model design, which relied on Qt 4 behavior.
  * Obey umask rules when saving new file (kde#343158)
  * Add meson HL
  * As Varnish 4.x introduces various syntax changes compared to
    Varnish 3.x, I wrote additional, separate syntax highlighting
    files for Varnish 4 (varnish4.xml, varnishtest4.xml).
  * Fix HiDPI issues
  * vimode: don't crash if the <c-e> command gets executed in the
    end of a document. (kde#350299)
  * Support QML multi-line strings.
  * Fix syntax of oors.xml
  * Add CartoCSS hl by Lukas Sommer (kde#340756)
  * Fix floating point HL, use the inbuilt Float like in C
    (kde#348843)
  * Split directions did got reversed (kde#348845)
  * Bug 348317 - [PATCH] Katepart syntax highlighting should
    recognize \u0123 style escapes for JavaScript (kde#348317)
  * Add *.cljs (kde#349844)
  * Update the GLSL highlighting file.
  * Fixed default colors to be more distinguishable
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * debianchangelog.xml: add Debian/Stretch, Debian/Buster, Ubuntu-Wily
  * Fix for UTF-16 surrogate pair backspace/delete behavior.
  * Let QScrollBar handle the WheelEvents (kde#340936)
  * Apply patch from KWrite devel top update pure basic HL
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Allow like in KDE 4.x times 3rdparty apps/plugins to install
    own highlighting XML files into katepart5/syntax
  * Add KTextEditor::Document::searchText()
  * Bring back use of KEncodingFileDialog (kde#343255)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Add kdesrc-buildrc highlighting file
  * syntax: added support for binary integer literals in the PHP
    highlighting file
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Add explicit kiconthemes-devel BuildRequires
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Add word count statistics in statusbar
  * vimode: fix crash when removing last line in Visual Line mode
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Fixed high-precision touchpad scrolling
  * Do not emit documentUrlChanged during reload
  * Do not break cursor position on document reload in
    lines with tabs
  * Do not re(un)fold the first line if it was
    manually (un)folded
  * vimode: command history through arrow keys
  * Do not try to create a digest when we get
    a KDirWatch::deleted() signal
  * Performance: remove global initializations
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * Fix build on MSVC.
  * vimode bugfixes
  * add syntax file for Oracle PL/SQL
  * ppd highlighting: better support for multiline values
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Fix kde#340212: incorrect soft-tabs alignment after
    beginning-of-line
  * Add libgit2 compile-time check for threads support
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * Implement "go to last editing position" action
  * Guard against a possibly broken code folding state on disk
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * Multiple memory leaks fixed
  * Avoid auto-completion to interfere with search/replace text
    (kde#339130), and more autocompletion fixes
  * Many fixes to the VIM mode
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
- Added libgit2-devel BuildRequires
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
- Added pkgconfig(Qt5Xml) and pkgconfig(Qt5XmlPatterns) BuildRequires
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Tue Apr 22 2014 hrvoje.senjan@gmail.com
- Removed sonnet-devel from devel package requires, not needed
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Activate KTextEditor package
